@@ -5,7 +5,8 @@ import time
 import board
 import adafruit_lps35hw
 
-i2c = board.I2C()
+i2c = board.I2C()  # uses board.SCL and board.SDA
+# i2c = board.STEMMA_I2C()  # For using the built-in STEMMA QT connector on a microcontroller
 lps = adafruit_lps35hw.LPS35HW(i2c)
 
 # set the current pressure as zero hPa and make measurements
